@@ -21,8 +21,11 @@
 #' | [mcse_mean()] | Monte Carlo standard error for the mean |
 #' | [mcse_quantile()] | Monte Carlo standard error for quantiles |
 #' | [mcse_sd()] | Monte Carlo standard error for standard deviations |
+#' | [pareto_khat()] | Pareto khat diagnostic for tail(s) |
+#' | [pareto_diags()] | Additional diagnostics related to Pareto khat |
 #' | [rhat_basic()] | Basic version of Rhat |
 #' | [rhat()] | Improved, rank-based version of Rhat |
+#' | [rhat_nested()] | Rhat for use with many short chains |
 #' | [rstar()] | R* diagnostic |
 #'
 #' @return
@@ -286,6 +289,10 @@ ess_median <- function(x, ...) {
     return(NA_real_)
   }
   x <- as.matrix(x)
+  if (prob == 1) {
+    len <- length(x)
+    prob <- (len - 0.5) / len
+  }
   I <- x <= quantile(x, prob)
   .ess(.split_chains(I))
 }
@@ -482,7 +489,7 @@ mcse_sd.default <- function(x, ...) {
   # has (X-E[X])^2. The following ESS is based on a relevant quantity
   # in the computation and is empirically a good choice.
   sims_c <- x - mean(x)
-  ess <- ess_mean(abs(sims_c))
+  ess <- ess_mean((sims_c)^2)
   # Variance of variance estimate by Kenney and Keeping (1951, p. 141),
   # which doesn't assume normality of sims.
   Evar <- mean(sims_c^2)
